const dropdownCss = theme => ({
  background: theme.colors.primaryBackground,
  border: `1px solid ${theme.colors.grey[10]}`,
  borderRadius: theme.radii[3],
  outline: "none",
  boxShadow: theme.shadows.floating,
  transformOrigin: "50% top",
  overflow: "auto",
  maxHeight: "20rem",
  // @TODO port to `Combobox` — providing this bit of vertical padding
  // aligns the first and last action items' visual size with the rest of the
  // dropdown items
  paddingTop: theme.space[3],
  paddingBottom: theme.space[3],
  // @TODO consider reserving purple background for `active` (CSS) and
  // `selected` states only — `hover` background could be light grey instead
  "[data-selected]": {
    background: theme.colors.purple[10],
    color: theme.colors.gatsby
  },
  [theme.mediaQueries.phablet]: {}
});
const dropdownSizeCss = {
  AUTO: _theme => ({}),
  MAX_CONTENT: _theme => ({
    width: `max-content`
  }),
  LEGACY: theme => ({
    width: `max-content`,
    [theme.mediaQueries.phablet]: {
      width: "80vw",
      maxWidth: "20rem"
    }
  })
};
const menuItemCss = theme => ({
  cursor: `pointer`,
  color: theme.colors.grey[90],
  fontSize: theme.fontSizes[1],
  // @TODO consider bumping horizontal, decrease vertical padding;
  // same goes for `Combobox`
  padding: `${theme.space[4]} ${theme.space[5]}`,
  lineHeight: theme.lineHeights.default,
  overflow: "hidden",
  wordWrap: `break-word`,
  overflowWrap: `break-word`,
  hyphens: `auto`,
  display: `block`,
  textDecoration: `none`
});
const dropdownButtonCss = theme => ({
  cursor: "pointer",
  display: "flex",
  alignItems: "center",
  border: `1px solid ${theme.colors.grey[30]}`,
  borderRadius: theme.radii[2],
  color: theme.colors.grey[90],
  fontSize: theme.fontSizes[2],
  padding: `${theme.space[2]} ${theme.space[4]}`,
  width: "100%",
  "&:focus": {
    borderColor: theme.colors.purple[40],
    boxShadow: `0 0 0 3px ${theme.colors.purple[20]}`,
    outline: 0,
    transition: `box-shadow 0.15s ease-in-out`
  }
});
const dropdownButtonIconCss = _theme => ({
  marginInlineStart: `auto`,
  transition: "transform .3s",
  "[aria-expanded] > &": {
    transform: "rotate(180deg)"
  }
});
const dropdownDividerCss = theme => ({
  // we're applying this to `hr`
  border: 0,
  borderTop: `1px solid ${theme.colors.grey[20]}`,
  marginBottom: theme.space[3],
  marginTop: theme.space[3]
});
const dropdownHeaderCss = theme => ({
  color: theme.colors.grey[50],
  fontFamily: theme.fonts.sans,
  fontSize: theme.fontSizes[0],
  fontWeight: theme.fontWeights.semiBold,
  margin: 0,
  padding: `${theme.space[4]} ${theme.space[5]}`
});

export { dropdownButtonCss, dropdownButtonIconCss, dropdownCss, dropdownDividerCss, dropdownHeaderCss, dropdownSizeCss, menuItemCss };
//# sourceMappingURL=DropdownMenu.styles.esm.js.map
