import { jsx } from '@emotion/core';
import _pt from 'prop-types';

const baseCss = theme => ({
  display: `inline-block`,
  fontFamily: theme.fonts.sans,
  fontSize: theme.fontSizes[0],
  lineHeight: theme.lineHeights.solid,
  fontWeight: theme.fontWeights.semiBold,
  backgroundColor: theme.colors.grey[20],
  color: theme.colors.grey[60],
  paddingLeft: `calc(3 * ${theme.space[1]})`,
  paddingRight: `calc(3 * ${theme.space[1]})`,
  paddingTop: theme.space[1],
  paddingBottom: theme.space[1],
  borderRadius: `10px`
});

const toneCss = {
  DANGER: theme => ({
    backgroundColor: theme.tones.DANGER.lighter,
    color: theme.tones.DANGER.superDark
  }),
  WARNING: theme => ({
    backgroundColor: theme.tones.WARNING.light,
    color: theme.tones.WARNING.textInverted
  }),
  NEUTRAL: theme => ({
    backgroundColor: theme.tones.NEUTRAL.light,
    color: theme.tones.NEUTRAL.dark
  })
};
function NumberBadge({
  tone = `NEUTRAL`,
  ...rest
}) {
  return jsx("span", {
    css: theme => [baseCss(theme), toneCss[tone](theme)],
    ...rest
  });
}
NumberBadge.propTypes = {
  tone: _pt.oneOf([`DANGER`, `WARNING`, `NEUTRAL`])
};

export { NumberBadge };
//# sourceMappingURL=NumberBadge.esm.js.map
